"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = require("react");
var react_native_navigation_1 = require("react-native-navigation");
/**
 * Registers listener to be called each time component appears on screen (attached to the view hierarchy)
 * [more info](https://wix.github.io/react-native-navigation/api/events/#componentdidappear)
 */
function useNavigationComponentDidAppear(
/**
 * Function called each time the event is triggered.
 */
handler, 
/**
 * Component reference id. If provided it listens for event only for this screen.
 */
componentId) {
    react_1.useLayoutEffect(function () {
        var subscription = react_native_navigation_1.Navigation.events().registerComponentDidAppearListener(function (event) {
            var equalComponentId = event.componentId === componentId;
            if (componentId && !equalComponentId) {
                return;
            }
            handler(event);
        });
        return function () { return subscription.remove(); };
    }, [handler, componentId]);
}
exports.useNavigationComponentDidAppear = useNavigationComponentDidAppear;
/**
 * Registers listener to be called each time component disappears from screen (detached from the view heirarchy) * [more info](https://wix.github.io/react-native-navigation/api/events/#componentdiddisappear)
 */
function useNavigationComponentDidDisappear(
/**
 * Function called each time the event is triggered.
 */
handler, 
/**
 * Component reference id. If provided it listens for event only for this screen.
 */
componentId) {
    react_1.useLayoutEffect(function () {
        var subscription = react_native_navigation_1.Navigation.events().registerComponentDidDisappearListener(function (event) {
            var equalComponentId = event.componentId === componentId;
            if (componentId && !equalComponentId) {
                return;
            }
            handler(event);
        });
        return function () { return subscription.remove(); };
    }, [handler, componentId]);
}
exports.useNavigationComponentDidDisappear = useNavigationComponentDidDisappear;
/**
 * Registers listener to be called when a Navigation command (i.e push, pop, showModal etc) is invoked.
 * [more info](https://wix.github.io/react-native-navigation/api/events/#registercommandlistener)
 */
function useNavigationCommand(
/**
 * Function called each time the event is triggered.
 */
handler, 
/**
 * Component reference id. If provided it listens for event only for this screen.
 */
commandName) {
    react_1.useLayoutEffect(function () {
        var subscription = react_native_navigation_1.Navigation.events().registerCommandListener(function (name, params) {
            var equalCommandName = name === commandName;
            if (commandName && !equalCommandName) {
                return;
            }
            handler(name, params);
        });
        return function () { return subscription.remove(); };
    }, [handler, commandName]);
}
exports.useNavigationCommand = useNavigationCommand;
/**
 * Registers listener to be called when a command finishes executing in native. If the command contains
 * animations, for example pushed screen animation) the listener is invoked after the animation ends.
 * [more info]https://wix.github.io/react-native-navigation/api/events/#registercommandcompletedlistener)
 */
function useNavigationCommandComplete(
/**
 * Function called each time the event is triggered.
 */
handler, 
/**
 * Name of the executed navegation command. Ex. "push".
 */
commandName) {
    react_1.useLayoutEffect(function () {
        var subscription = react_native_navigation_1.Navigation.events().registerCommandCompletedListener(function (event) {
            var equalCommandName = event.commandName === commandName;
            if (commandName && !equalCommandName) {
                return;
            }
            handler(event);
        });
        return function () { return subscription.remove(); };
    }, [handler, commandName]);
}
exports.useNavigationCommandComplete = useNavigationCommandComplete;
/**
 * Registers listener to be called only on iOS pageSheet modal when swipeToDismiss flag is set to true and modal * swiped down to dismiss.
 * [more info](https://wix.github.io/react-native-navigation/apievents#registermodalattemptedtodismisslistenerios-13-only)
 */
function useNavigationModalAttemptedToDismiss(
/**
 * Function called each time the event is triggered.
 */
handler, 
/**
 * Component reference id. If provided it listens for event only for this screen.
 */
componentId) {
    react_1.useLayoutEffect(function () {
        var subscription = react_native_navigation_1.Navigation.events().registerModalAttemptedToDismissListener(function (event) {
            var equalCommandId = event.componentId === componentId;
            if (componentId && !equalCommandId) {
                return;
            }
            handler(event);
        });
        return function () { return subscription.remove(); };
    }, [handler, componentId]);
}
exports.useNavigationModalAttemptedToDismiss = useNavigationModalAttemptedToDismiss;
/**
 * Registers listener to be called when modal is dismissed.
 * [more info](https://wix.github.io/react-native-navigation/api/events/#registermodaldismissedlistener)
 */
function useNavigationModalDismiss(
/**
 * Function called each time the event is triggered.
 */
handler, 
/**
 * Component reference id. If provided it listens for event only for this screen.
 */
componentId) {
    react_1.useLayoutEffect(function () {
        var subscription = react_native_navigation_1.Navigation.events().registerModalDismissedListener(function (event) {
            var equalComponentId = event.componentId === componentId;
            if (componentId && !equalComponentId) {
                return;
            }
            handler(event);
        });
        return function () { return subscription.remove(); };
    }, [handler, componentId]);
}
exports.useNavigationModalDismiss = useNavigationModalDismiss;
/**
 * Registers listener to be called when screen is popped.
 * [more info](https://wix.github.io/react-native-navigation/api/events/#registerscreenpoppedlistener)
 */
function useNavigationScreenPop(
/**
 * Function called each time the event is triggered.
 */
handler, 
/**
 * Component reference id. If provided it listens for event only for this screen.
 */
componentId) {
    react_1.useLayoutEffect(function () {
        var subscription = react_native_navigation_1.Navigation.events().registerScreenPoppedListener(function (event) {
            var equalCommandId = event.componentId === componentId;
            if (componentId && !equalCommandId) {
                return;
            }
            handler(event);
        });
        return function () { return subscription.remove(); };
    }, [handler, componentId]);
}
exports.useNavigationScreenPop = useNavigationScreenPop;
/**
 * Registers listener to be called when a BottomTab is selected by the user.
 * [more info](https://wix.github.io/react-native-navigation/api/events/#registerbottomtabselectedlistener)
 */
function useNavigationBottomTabSelect(
/**
 * Function called each time the event is triggered.
 */
handler) {
    react_1.useLayoutEffect(function () {
        var subscription = react_native_navigation_1.Navigation.events().registerBottomTabSelectedListener(handler);
        return function () { return subscription.remove(); };
    }, [handler]);
}
exports.useNavigationBottomTabSelect = useNavigationBottomTabSelect;
/**
 * Registers listener to be called when a BottomTab is pressed by the user.
 * [more info](https://wix.github.io/react-native-navigation/api/events/#registerbottomtabpressedlistener)
 */
function useNavigationBottomTabPress(
/**
 * Function called each time the event is triggered.
 */
handler) {
    react_1.useLayoutEffect(function () {
        var subscription = react_native_navigation_1.Navigation.events().registerBottomTabPressedListener(handler);
        return function () { return subscription.remove(); };
    }, [handler]);
}
exports.useNavigationBottomTabPress = useNavigationBottomTabPress;
/**
 * Registers listener to be called when a BottomTab is long pressed by the user.
 * [more info](https://wix.github.io/react-native-navigation/api/events/#registerbottomtablongpressedlistener)
 */
function useNavigationBottomTabLongPress(
/**
 * Function called each time the event is triggered.
 */
handler) {
    react_1.useLayoutEffect(function () {
        var subscription = react_native_navigation_1.Navigation.events().registerBottomTabLongPressedListener(handler);
        return function () { return subscription.remove(); };
    }, [handler]);
}
exports.useNavigationBottomTabLongPress = useNavigationBottomTabLongPress;
/**
 * Registers listener to be called when a TopBar button is pressed by the user.
 * [more info](https://wix.github.io/react-native-navigation/api/events/#navigationbuttonpressed-event)
 */
function useNavigationButtonPress(
/**
 * Function called each time the event is triggered.
 */
handler, 
/**
 * Component reference id. If provided it listens for event only for this screen.
 */
componentId, 
/**
 * Navigation button reference id.
 */
buttonId) {
    react_1.useLayoutEffect(function () {
        var subscription = react_native_navigation_1.Navigation.events().registerNavigationButtonPressedListener(function (event) {
            var equalComponentId = event.componentId === componentId;
            var equalButtonId = event.buttonId === buttonId;
            if ((componentId && !equalComponentId) || (buttonId && !equalButtonId)) {
                return;
            }
            handler(event);
        });
        return function () { return subscription.remove(); };
    }, [handler, componentId, buttonId]);
}
exports.useNavigationButtonPress = useNavigationButtonPress;
/**
 * Registers listener to be called when a SearchBar from NavigationBar gets updated.
 * [more info](https://wix.github.io/react-native-navigation/api/events/#searchbarupdated-ios-11-only)
 */
function useNavigationSearchBarUpdate(
/**
 * Function called each time the event is triggered.
 */
handler, 
/**
 * Component reference id. If provided it listens for event only for this screen.
 */
componentId) {
    react_1.useLayoutEffect(function () {
        var subscription = react_native_navigation_1.Navigation.events().registerSearchBarUpdatedListener(function (event) {
            var equalComponentId = event.componentId === componentId;
            if (componentId && !equalComponentId) {
                return;
            }
            handler(event);
        });
        return function () { return subscription.remove(); };
    }, [handler, componentId]);
}
exports.useNavigationSearchBarUpdate = useNavigationSearchBarUpdate;
/**
 * Registers listener to be called when the cancel button on the SearchBar from NavigationBar gets pressed.
 * [more info](https://wix.github.io/react-native-navigation/api/events/#searchbarcancelpressed-ios-11-only)
 */
function useNavigationSearchBarCancelPress(
/**
 * Function called each time the event is triggered.
 */
handler, 
/**
 * Component reference id. If provided it listens for event only for this screen.
 */
componentId) {
    react_1.useLayoutEffect(function () {
        var subscription = react_native_navigation_1.Navigation.events().registerSearchBarCancelPressedListener(function (event) {
            var equalComponentId = event.componentId === componentId;
            if (componentId && !equalComponentId) {
                return;
            }
            handler(event);
        });
        return function () { return subscription.remove(); };
    }, [handler, componentId]);
}
exports.useNavigationSearchBarCancelPress = useNavigationSearchBarCancelPress;
/**
 * Registers listener to be called when preview peek is completed.
 * [more info](https://wix.github.io/react-native-navigation/api/events/#previewcompleted-ios-114-only)
 */
function useNavigationPreviewComplete(
/**
 * Function called each time the event is triggered.
 */
handler, 
/**
 * Component reference id. If provided it listens for event only for this screen.
 */
componentId) {
    react_1.useLayoutEffect(function () {
        var subscription = react_native_navigation_1.Navigation.events().registerPreviewCompletedListener(function (event) {
            var equalComponentId = event.componentId === componentId;
            if (componentId && !equalComponentId) {
                return;
            }
            handler(event);
        });
        return function () { return subscription.remove(); };
    }, [handler, componentId]);
}
exports.useNavigationPreviewComplete = useNavigationPreviewComplete;
//# sourceMappingURL=index.js.map